/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "NodeFilter.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomNodeFilter.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomNodeFilter.h"
#include "gdom/PrivateIntGdomNodeFilter.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::NodeFilter* obj)
{
    return WebCore::cacheDOMObject<WebCore::NodeFilter, GDOMNodeFilter>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMNodeFilter::GDOMNodeFilter(PassRefPtr<WebCore::NodeFilter> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMNodeFilter::~GDOMNodeFilter()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}


/* XXX TODO: custom function gdom_node_filter_accept_node */

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "NodeFilter.h"
#include <gdom/GdomNodeFilter.h>
#include <gdom/PrivateGdomNodeFilter.h>
#include <gdom/PrivateIntGdomNodeFilter.h>
#include <gdom/GdomNodeFilterprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomNodeFilter, gdom_node_filter, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomNodeFilterPrivate {
    class WebCore::NodeFilter *item;
};

#define GDOM_NODE_FILTER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_NODE_FILTER, GdomNodeFilterPrivate))
*/
G_END_DECLS
WebCore::NodeFilter *
gdom_node_filter_get_private(GdomNodeFilter *request)
{
    GDOMNodeFilter *res;
    res = static_cast<GDOMNodeFilter*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::NodeFilter*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
};


static void gdom_node_filter_finalize(GObject* object)
{
    /*GdomNodeFilter* request = GDOM_NODE_FILTER(object);*/
    /*GdomNodeFilterPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_node_filter_parent_class)->finalize(object);
}

static void gdom_node_filter__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomNodeFilter *self = GDOM_NODE_FILTER(object);
    WebCore::NodeFilter * gself = (gdom_node_filter_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_node_filter__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomNodeFilter *self = GDOM_NODE_FILTER(object);
    WebCore::NodeFilter * gself = (gdom_node_filter_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_node_filter_class_init(GdomNodeFilterClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_node_filter_finalize;
    g_klass->set_property = gdom_node_filter__set_property_fn;
    g_klass->get_property = gdom_node_filter__get_property_fn;





    /*g_type_class_remove_private(requestClass, sizeof(GdomNodeFilterPrivate));*/
}

static void gdom_node_filter_init(GdomNodeFilter* request)
{
    /*GdomNodeFilterPrivate* priv = GDOM_NODE_FILTER_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

